#
# spec file for package evolution-rss
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _eds_moduledir %(pkg-config --variable privlibdir libedataserver-1.2)/registry-modules
%define _evo_branch %(pkg-config --variable execversion evolution-shell-3.0)
%define _evo_plugindir %(pkg-config --variable privlibdir evolution-shell-3.0)/plugins
%define _evo_imagesdir %(pkg-config --variable imagesdir evolution-shell-3.0)
%define         _name evolution-plugin-rss
%define _evo_errordir %(pkg-config --variable errordir evolution-shell-3.0)

Name:           evolution-rss
Version:        0.3.96
Release:        bp154.1.156
Summary:        Evolution Plugin for RSS Feeds Support
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Email/Clients
URL:            http://gnome.eu.org/evo/index.php/Evolution_RSS_Reader_Plugin
Source:         %{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM evolution-rss-drop-gconf-for-good.patch -- Drop gconf2 for good.
Patch:          evolution-rss-drop-gconf-for-good.patch

BuildRequires:  gcc-c++
BuildRequires:  gnome-common
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(evolution-data-server-1.2)
BuildRequires:  pkgconfig(evolution-shell-3.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.26
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libebook-1.2)
BuildRequires:  pkgconfig(libemail-engine)
BuildRequires:  pkgconfig(libsoup-2.4)
Provides:       %{_name} = %{version}

%description
This plugin for Evolution adds RSS Feeds support and enables the use of
Evolution as a RSS Reader.

%package -n %{_name}
Summary:        Evolution Plugin for RSS Feeds Support
Group:          Productivity/Networking/Email/Clients
Provides:       %{name} = %{version}

%description -n %{_name}
This plugin for Evolution adds RSS Feeds support and enables the use of
Evolution as a RSS Reader.

%lang_package -n %{_name}

%prep
%autosetup -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
	--disable-schemas-install \
	%{nil}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}

%files -n %{_name}
%{_bindir}/evolution-import-rss
%{_datadir}/metainfo/evolution-rss.metainfo.xml
%{_datadir}/applications/evolution-rss.desktop
%{_datadir}/evolution/ui/rss-html-rendering.ui
%{_datadir}/evolution/ui/rss-main.ui
%{_datadir}/GConf/gsettings/evolution-rss.convert
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.plugin.evolution-rss.gschema.xml
%{_eds_moduledir}/module-eds-rss.so
%{_evo_errordir}/org-gnome-evolution-rss.error
%{_evo_imagesdir}/pix.png
%{_evo_imagesdir}/rss-16.png
%{_evo_imagesdir}/rss-22.png
%{_evo_imagesdir}/rss-24.png
%{_evo_imagesdir}/rss-icon-read.png
%{_evo_imagesdir}/rss-icon-unread.png
%{_evo_imagesdir}/rss-text-html.png
%{_evo_imagesdir}/rss-text-x-generic.png
%{_evo_imagesdir}/rss.png
%{_evo_plugindir}/liborg-gnome-evolution-rss.so
%{_evo_plugindir}/org-gnome-evolution-rss.eplug
%{_evo_plugindir}/org-gnome-evolution-rss.xml
%{_libdir}/evolution/modules/evolution-module-rss.so

%files -n %{_name}-lang -f %{name}.lang

%changelog
* Fri Jan 31 2020 bjorn.lie@gmail.com
- Update to version 0.3.96:
  + Miscellaneous build fixes (multiple declarations of variables)
  + Fix use-after-free under rss_ep_need_proxy_http()
  + EMailFormatterRSS: Remove unneeded fetch of EWebView content
  + Remove markup from strings in UI files
  + Use Unicode in translatable strings
  + Fix AppStream metainfo validation
  + Don't use legacy path for AppStream metainfo file
  + Replace Bugzilla by Gitlab URL in DOAP file
  + Avoid crash when feed formatting is cancelled
  + Updated translations.
- Change _service file as we now have a proper upstream released
  tag that we want to use.
- Drop evolution-rss-use-unicode.patch: Fixed upstream.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Thu Mar 28 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Drop unused pkgconfig(gtkhtml-editor-4.0) BuildRequires.
* Wed Jun 13 2018 bjorn.lie@gmail.com
- Add evolution-rss-drop-gconf-for-good.patch: Drop gconf2 for
  good (glgo#GNOME/evolution-rss/#2).
- Following the above patch, drop gconf2-devel BuildRequires and
  glib2_gsettings_schema_requires macro: No longer mandatory.
- Add evolution-rss-use-unicode.patch: Use Unicode in translatable
  strings and remove markup from strings in UI files
  (glgo#GNOME/evolution-rss/#1).
- Drop post(un) handling of glib2_gsettings_schema_post(un), no
  longer needed on new versions of openSUSE.
- Drop update-desktop-files BuildRequires and
  suse_update_desktop_file macro, no longer needed.
- Modernize spec, use autosetup and make_build macros.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Feb  6 2018 dimstar@opensuse.org
- Update to version 0.3.95+git.20171129:
  + Crash when importing OPML file with feeds without 'title'
    attribute.
  + gschema: Fix gettext-domain
  + Updated translations.
* Thu Sep 14 2017 fezhang@suse.com
- Drop the pre- SLE12 / Leap42 conditional for _evo_errordir.
* Fri Feb  3 2017 zaitor@opensuse.org
-  Drop pkgconfig(webkitgtk-3.0) BuildRequires: We build against
  evolution 3.22.x or newer, and support for webkitgtk-3.0 has
  been dropped upstream for this version and newer in both
  evolution-rss and evolution.
* Mon Jan 16 2017 dimstar@opensuse.org
- Update to version 0.3.95+git.20161130:
  + Fix typo in Spanish translation header.
  + bgo#764065: [Camel] Port more classes to GObject.
  + Updated translations.
* Wed Aug 17 2016 dimstar@opensuse.org
- Update to version 0.3.95+git.20160817:
  + bgo#752197: Teach cache-reaper of 3rd-party private
    directories.
  + bgo#752197: Correct undefined cache reaper symbols from the
    link time.
  + Do not use global variables for EShellView and EShellWindow.
  + add formater libs to the missing libs defs.
  + various cleanups.
  + Fix spelling of "OK" in a translatable string.
  + Adapt to changes in evolution 3.21.90.
  + Auto-disable WebKit support when compiled against evolution
    3.21.90+.
  + Updated translations.
* Fri Jun 26 2015 dimstar@opensuse.org
- Fix build for openSUSE 42 (possibly breaking clean SLE12).
* Wed Apr  8 2015 dimstar@opensuse.org
- Update to version 0.3.95:
  + Don't crash on failed plugin initialization.
  + Fix show placeholder rss icon.
  + bgo#746511: E: evolution-rss no-return-in-nonvoid-function.
  + bgo#741570: Typo in translatable string.
  + Add appdata files to dist target.
  + Updated translations.
- Drop 0001-Fix-compiler-warning.patch: fixed upstream.
* Fri Mar 20 2015 dimstar@opensuse.org
- Add 0001-Fix-compiler-warning.patch: Fix compiler warning.
* Thu Mar 19 2015 dimstar@opensuse.org
- Update to version 0.3.95~20150316:
  + Updated Greek translation
  + better handle enclosures obey filesize if present
  + fix subject on enclosured feed messages
  + fix subject on feeds (take II) and bring back categories
  + Updated Hungarian translation
  + Updated Polish translation
  + Updated Czech translation
  + don't crash on freeing category
  + bring back feeds comments
  + hide individual feed errors by default it gests annoying to
    have a lot of errors alert dialogs for each feed every time it
    is fetched.
  + Added Bosnian translation
  + Updated Lithuanian translation
  + Updated Swedish translation
* Thu Feb 19 2015 opensuse-packaging@opensuse.org
- Update to version 0.3.95~20150213:
  + add link/href parsing (fixes html rendering).
  + make feed enclosures work again.
- Add gnome-common and gconf2-devel BuildRequires and call to
  autogen.sh.
* Wed Jan 28 2015 dimstar@opensuse.org
- Updated files section for Evolution 3.13.x.
* Thu Nov 20 2014 fstrba@suse.com
- Update to git master (0.3.95~git20141120.b2253df):
  + Fixes miscellaneous crashes while editing feeds.
  + General improvement of stability.
- Drop upstreamed patches:
  + evolution-rss-EMailPart.patch
  + evolution-rss-ESEvent.patch
  + evolution-rss-evo3.11.3.patch
  + evolution-rss-evo3.11.91.patch
  + evolution-rss-evo3.11.patch
  + evolution-rss-remove-EShellSettings-requirements.patch
- Detect the _evo_errordir with the same logic as the
  m4/evolution.m4: allows building for SLE12.
* Sun Oct  5 2014 dimstar@opensuse.org
- Do not show evolution-rss in the menu: it's integrated into
  evolution directly (suse_update_desktop_files -u).
* Tue Mar  4 2014 dimstar@opensuse.org
- Add evolution-rss-evo3.11.91.patch: Fix build with evolution
  3.11.91.
- Drop evolution-rss-soup-linking.patch: obsoleted by above patch.
* Sat Jan 11 2014 dimstar@opensuse.org
- Add evolution-rss-evo3.11.3.patch: Fix build with evolution
  3.11.3.
* Mon Dec  2 2013 dimstar@opensuse.org
- Add evolution-rss-evo3.11.patch: Fix build with evolution 3.11.2.
* Mon Sep  2 2013 dimstar@opensuse.org
- Add evolution-rss-ESEvent.patch: Adapt to ESEvent changes in
  Evolution 3.9.
* Thu Jul  4 2013 dimstar@opensuse.org
- Add evolution-rss-EMailPart.patch: adapt to EMailPart changes in
  Evolution 3.9.3.
* Sun May 12 2013 dimstar@opensuse.org
- Add evolution-rss-remove-EShellSettings-requirements.patch: Fix
  build with evolution 3.9.
* Sun Mar 10 2013 dimstar@opensuse.org
- Add evolution-rss-soup-linking.patch: link the plugin against
  libsoup, so it can be loaded.
- Add gnome-common and gconf2-devel BuildRequries and call to
  gnome-autogen.sh, as above patch touches the build system.
* Sat Mar  9 2013 dimstar@opensuse.org
- Update to version 0.3.93:
  + Adapt to evolution API changes.
  + Bugs fixed: bgo#684120, bgo#686142.
  + Updated translations.
- Drop pkgconfig(libemail-utils) and pkgconfig(libevolution-utils
  BuildRequires: no longer needed.
* Fri Jan 18 2013 dimstar@opensuse.org
- Add the post/postun scriptlet to the actual package (bnc#794866).
* Fri Sep 14 2012 dimstar@opensuse.org
- Update to version 0.3.92:
  + Fix gconf migration
  + Adapt to latest evo/eds changes
  + Port to GSettings.
  + Updated translations.
- Drop xz BuildRequires, as it now comes for free in the build
  system.
- Replace %%gconf schema handling macros with %%glib variants.
* Wed Jun 13 2012 badshah400@gmail.com
- Added pkgconfig(libemail-utils), pkgconfig(libevolution-utils),
  pkgconfig(libemail-engine) as the configure script checks for
  these explicitly, and fails if they are not present; makes
  building unresolvable (instead of failing) for openSUSE <= 12.1.
* Fri Apr  6 2012 vuntz@opensuse.org
- Update to version 0.3.91:
  + Additional fixes for compatibility with evolution 3.4.
  + Fix memory leaks.
- Drop evolution-rss-evo-3.4.patch: fixed upstream.
- Remove gnome-common BuildRequires and call to gnome-autogen.sh,
  that were only needed for above patch.
* Wed Feb 29 2012 vuntz@opensuse.org
- Add evolution-rss-evo-3.4.patch: commits from git to fix build
  with evolution 3.4.
- Add gnome-common BuildRequires and call to gnome-autogen.sh,
  needed for above patch.
* Fri Jan  6 2012 vuntz@opensuse.org
- Update to version 0.3.90 (git commit cac58a2f - not released), to
  fix build with evolution 3.3:
  + Fix build against evolution 3.1.x/3.2.x/3.3.x.
  + Small bug fixes.
  + Build fixes.
- Drop evolution-rss-evo311.patch, evolution-rss-evo314.patch,
  evolution-rss-evo315.patch, evolution-rss-gtk_hvbox_new.patch:
  patches all included in the new git checkout.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Add update-desktop-files BuildRequires and call to
  %%suse_update_desktop_file for new .desktop files: while not
  needed for Factory/12.2, we still support previous versions of
  openSUSE in this package.
* Wed Sep 28 2011 vuntz@opensuse.org
- Add evolution-rss-evo315.patch: fix build with evolution 3.1.5,
  taken from git.
* Sun Aug  7 2011 dimstar@opensuse.org
- Add evolution-rss-evo314.patch: Adapt to changes in evo 3.1.4.
  Patch taken from upstream git
- Add evoltution-rss-gtk_hbvox_new.patch: Stop using depreacated
  gtk_[hv]box_new calls. Patch submitted as bgo#656126.
* Thu Jun  2 2011 vuntz@opensuse.org
- Drop now unneeded libgnomecanvas-devel BuildRequires.
- Change libwebkitgtk-devel BuildRequires to
  pkgconfig(webkitgtk-3.0).
- Add explicit pkgconfig() BuildRequires instead of relying on
  other packages to bring them in: evolution-data-server-1.2,
  glib-2.0, libebook-1.2, libsoup-2.4, evolution-plugin-3.0,
  gtk+-3.0, gtkhtml-editor-4.0.
* Wed Jun  1 2011 dimstar@opensuse.org
- Forward to git commit 11637dc: support evolution 3.1.1.
- Add evolution-rss-evo311.patch: the evolution-rss git snapshot is
  against evolution master, which is still called 3.1.1.
* Mon May 16 2011 dimstar@opensuse.org
- Update to version 0.2.90 (git commit 592138d - not released), to
  fix build with evolution 3.0 and gtk+ 3.0. New features and bug
  fixes from git will be listed on update to 0.2.90.
- Change evolution-devel BuildRequires to
  pkgconfig(evolution-shell-3.0).
- Update the evo_* defines to reflect evolution 3.0 names (e.g.
  evolution-shell => evolution-shell-3.0)
* Mon May 16 2011 dimstar@opensuse.org
- Update to version 0.2.5:
  + Miscellaneous Fixes:
  - Fix export function
  - Improve debug output
  - Fix deleting folder contents
  - Make opml filter default when exporting
  - Add default export file name
  + Bugs fixed: bgo#648559, bgo#648490, bgo#647142, bgo#644100.
  + Updated translations.
* Wed May  4 2011 dimstar@opensuse.org
- Update to version 0.2.4:
  + bgo#643187: url redirection for enclosures doesn't work as
    expected.
  + bgo#643050: crash on moving rss-folder.
  + bgo#642357: crash on parsing RSS feed.
  + bgo#641237: Importing RDF feed fails.
* Mon Feb 14 2011 vuntz@opensuse.org
- Update to version 0.2.3:
  + Fix parsing of ref=alternate nodes
  + Do not pass empty string to strcasecmp
  + Fix fetch feed operation progress bar
  + Allow build with newer webkit
  + Fix parsing children nodes
  + Remove excesive debug warnings
  + Init rss folder hooks later
  + Print imported feed url in case cannot lookup channel name
  + Use ref alternate in atom feeds to get feed link
  + Bug fixes: bgo#639825, bgo#639942, bgo#638297.
* Fri Jan  7 2011 vuntz@opensuse.org
- Update to version 0.2.2:
  + Remove warnings on missing shellview.
  + Fix render engine combo.
  + Fix gtkhtml detection.
  + Fix sending RSS articles as mails.
  + Improve displaying of folder icons (it greately speeds up the
    loading)
  + bgo#635157: Bad character encoding when showing full text
  + bgo#636053: Host-relative links in atom feed don't work
- Changes from version 0.2.1:
  + Add support for evolution 2.32.
- Remove gnome-common BuildRequires and call to ./autogen.sh since
  this is no longer a git snapshot.
- Add Url tag.
* Thu Nov 18 2010 aj@suse.de
- Add libgnomecanvas-devel as BuildRequires to fix build.
* Sun Oct  3 2010 dimstar@opensuse.org
- Initial package, based on current git commit 686d979. Latest
  version was 0.2.0, this the version 0.2.0+git. 0.2.0 does not
  work with Evolution 2.32 due to architecture changes of evo.
